@@ -18,9 +18,9 @@ rpm --checksig kernel-2.6.34.9-69.fc13.src.rpm || die "Can't verify signature."
 rpm -ivh kernel-2.6.34.9-69.fc13.src.rpm || die "Can't install source package."
 
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.2-20110726.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20110929.tar.gz ]
 then
-    wget -O ccs-patch-1.8.2-20110726.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.2-20110726.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20110929.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20110929.tar.gz' || die "Can't download patch."
 fi
 
 cd /root/rpmbuild/SPECS/ || die "Can't chdir to /root/rpmbuild/SPECS/ ."
@@ -33,7 +33,7 @@ patch << "EOF" || die "Can't patch spec file."
  # (Uncomment the '#' and both spaces below to set the buildid.)
  #
 -# % define buildid .local
-+%define buildid _tomoyo_1.8.2p2
++%define buildid _tomoyo_1.8.3
  ###################################################################
  
  # The buildid can also be specified on the rpmbuild command line
@@ -72,7 +72,7 @@ patch << "EOF" || die "Can't patch spec file."
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.2-20110726.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.8.3-20110929.tar.gz
 +patch -sp1 < patches/ccs-patch-2.6.34-fedora-13.diff
 +
  %endif
