@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.8.1   2011/04/01
+ * Version: 1.8.3   2011/09/29
  */
 
 #include "internal.h"
@@ -29,12 +29,6 @@ void ccs_warn_oom(const char *function)
 		panic("MAC Initialization failed.\n");
 }
 
-/*
- * Lock for protecting ccs_memory_used.
- *
- * I don't use atomic_t because it can handle only 16MB in 2.4 kernels.
- */
-static DEFINE_SPINLOCK(ccs_policy_memory_lock);
 /* Memoy currently used by policy/audit log/query. */
 unsigned int ccs_memory_used[CCS_MAX_MEMORY_STAT];
 /* Memory quota for "policy"/"audit log"/"query". */
@@ -47,22 +41,19 @@ unsigned int ccs_memory_quota[CCS_MAX_MEMORY_STAT];
  * @size: Size in byte. Not used if @ptr is NULL.
  *
  * Returns true if @ptr is not NULL and quota not exceeded, false otherwise.
+ *
+ * Caller holds ccs_policy_lock mutex.
  */
 bool ccs_memory_ok(const void *ptr, const unsigned int size)
 {
 	if (ptr) {
 		const size_t s = ccs_round2(size);
-		bool result;
-		spin_lock(&ccs_policy_memory_lock);
 		ccs_memory_used[CCS_MEMORY_POLICY] += s;
-		result = !ccs_memory_quota[CCS_MEMORY_POLICY] ||
-			ccs_memory_used[CCS_MEMORY_POLICY] <=
-			ccs_memory_quota[CCS_MEMORY_POLICY];
-		if (!result)
-			ccs_memory_used[CCS_MEMORY_POLICY] -= s;
-		spin_unlock(&ccs_policy_memory_lock);
-		if (result)
+		if (!ccs_memory_quota[CCS_MEMORY_POLICY] ||
+		    ccs_memory_used[CCS_MEMORY_POLICY] <=
+		    ccs_memory_quota[CCS_MEMORY_POLICY])
 			return true;
+		ccs_memory_used[CCS_MEMORY_POLICY] -= s;
 	}
 	ccs_warn_oom(__func__);
 	return false;
@@ -76,6 +67,8 @@ bool ccs_memory_ok(const void *ptr, const unsigned int size)
  *
  * Returns pointer to allocated memory on success, NULL otherwise.
  * @data is zero-cleared on success.
+ *
+ * Caller holds ccs_policy_lock mutex.
  */
 void *ccs_commit_ok(void *data, const unsigned int size)
 {
@@ -89,35 +82,20 @@ void *ccs_commit_ok(void *data, const unsigned int size)
 	return NULL;
 }
 
-/**
- * ccs_memory_free - Free memory for elements.
- *
- * @ptr:  Pointer to allocated memory.
- * @size: Size in byte.
- *
- * Returns nothing.
- */
-void ccs_memory_free(const void *ptr, size_t size)
-{
-	size_t s = ccs_round2(size);
-	spin_lock(&ccs_policy_memory_lock);
-	ccs_memory_used[CCS_MEMORY_POLICY] -= s;
-	spin_unlock(&ccs_policy_memory_lock);
-	kfree(ptr);
-}
-
 /**
  * ccs_get_group - Allocate memory for "struct ccs_path_group"/"struct ccs_number_group"/"struct ccs_address_group".
  *
- * @group_name: The name of address group.
- * @idx:        Index number.
+ * @param: Pointer to "struct ccs_acl_param".
+ * @idx:   Index number.
  *
  * Returns pointer to "struct ccs_group" on success, NULL otherwise.
  */
-struct ccs_group *ccs_get_group(const char *group_name, const u8 idx)
+struct ccs_group *ccs_get_group(struct ccs_acl_param *param, const u8 idx)
 {
 	struct ccs_group e = { };
 	struct ccs_group *group = NULL;
+	struct list_head *list;
+	const char *group_name = ccs_read_token(param);
 	bool found = false;
 	if (!ccs_correct_word(group_name) || idx >= CCS_MAX_GROUP)
 		return NULL;
@@ -126,8 +104,10 @@ struct ccs_group *ccs_get_group(const char *group_name, const u8 idx)
 		return NULL;
 	if (mutex_lock_interruptible(&ccs_policy_lock))
 		goto out;
-	list_for_each_entry(group, &ccs_group_list[idx], head.list) {
-		if (e.group_name != group->group_name)
+	list = &param->ns->group_list[idx];
+	list_for_each_entry(group, list, head.list) {
+		if (e.group_name != group->group_name ||
+		    atomic_read(&group->head.users) == CCS_GC_IN_PROGRESS)
 			continue;
 		atomic_inc(&group->head.users);
 		found = true;
@@ -138,8 +118,7 @@ struct ccs_group *ccs_get_group(const char *group_name, const u8 idx)
 		if (entry) {
 			INIT_LIST_HEAD(&entry->member_list);
 			atomic_set(&entry->head.users, 1);
-			list_add_tail_rcu(&entry->head.list,
-					  &ccs_group_list[idx]);
+			list_add_tail_rcu(&entry->head.list, list);
 			group = entry;
 			found = true;
 		}
@@ -150,46 +129,6 @@ out:
 	return found ? group : NULL;
 }
 
-/**
- * ccs_get_ipv6_address - Keep the given IPv6 address on the RAM.
- *
- * @addr: Pointer to "struct in6_addr".
- *
- * Returns pointer to "struct in6_addr" on success, NULL otherwise.
- */
-const struct in6_addr *ccs_get_ipv6_address(const struct in6_addr *addr)
-{
-	struct ccs_ipv6addr *entry;
-	struct ccs_ipv6addr *ptr = NULL;
-	int error = -ENOMEM;
-	if (!addr)
-		return NULL;
-	entry = kzalloc(sizeof(*entry), CCS_GFP_FLAGS);
-	if (mutex_lock_interruptible(&ccs_policy_lock))
-		goto out;
-	list_for_each_entry(ptr, &ccs_shared_list[CCS_IPV6ADDRESS_LIST],
-			    head.list) {
-		if (memcmp(&ptr->addr, addr, sizeof(*addr)))
-			continue;
-		atomic_inc(&ptr->head.users);
-		error = 0;
-		break;
-	}
-	if (error && ccs_memory_ok(entry, sizeof(*entry))) {
-		ptr = entry;
-		ptr->addr = *addr;
-		atomic_set(&ptr->head.users, 1);
-		list_add_tail(&ptr->head.list,
-			      &ccs_shared_list[CCS_IPV6ADDRESS_LIST]);
-		entry = NULL;
-		error = 0;
-	}
-	mutex_unlock(&ccs_policy_lock);
-out:
-	kfree(entry);
-	return !error ? &ptr->addr : NULL;
-}
-
 /* The list for "struct ccs_name". */
 struct list_head ccs_name_list[CCS_MAX_HASH];
 
@@ -220,7 +159,8 @@ const struct ccs_path_info *ccs_get_name(const char *name)
 	if (mutex_lock_interruptible(&ccs_policy_lock))
 		return NULL;
 	list_for_each_entry(ptr, head, head.list) {
-		if (hash != ptr->entry.hash || strcmp(name, ptr->entry.name))
+		if (hash != ptr->entry.hash || strcmp(name, ptr->entry.name) ||
+		    atomic_read(&ptr->head.users) == CCS_GC_IN_PROGRESS)
 			continue;
 		atomic_inc(&ptr->head.users);
 		goto out;
@@ -400,6 +340,9 @@ static void __ccs_free_task_security(const struct task_struct *task)
 
 #endif
 
+/* Initial namespace.*/
+struct ccs_policy_namespace ccs_kernel_namespace;
+
 /**
  * ccs_mm_init - Initialize mm related code.
  *
@@ -410,12 +353,10 @@ void __init ccs_mm_init(void)
 	int idx;
 	for (idx = 0; idx < CCS_MAX_HASH; idx++)
 		INIT_LIST_HEAD(&ccs_name_list[idx]);
-	for (idx = 0; idx < CCS_MAX_ACL_GROUPS; idx++) {
-		INIT_LIST_HEAD(&ccs_acl_group[idx].acl_info_list[0]);
-		INIT_LIST_HEAD(&ccs_acl_group[idx].acl_info_list[1]);
-	}
-	INIT_LIST_HEAD(&ccs_kernel_domain.acl_info_list[0]);
-	INIT_LIST_HEAD(&ccs_kernel_domain.acl_info_list[1]);
+	ccs_kernel_namespace.name = "<kernel>";
+	ccs_init_policy_namespace(&ccs_kernel_namespace);
+	ccs_kernel_domain.ns = &ccs_kernel_namespace;
+	INIT_LIST_HEAD(&ccs_kernel_domain.acl_info_list);
 #ifdef CONFIG_CCSECURITY_USE_EXTERNAL_TASK_SECURITY
 	for (idx = 0; idx < CCS_MAX_TASK_SECURITY_HASH; idx++)
 		INIT_LIST_HEAD(&ccs_task_security_list[idx]);
@@ -425,27 +366,6 @@ void __init ccs_mm_init(void)
 	ccsecurity_ops.alloc_task_security = __ccs_alloc_task_security;
 	ccsecurity_ops.free_task_security = __ccs_free_task_security;
 #endif
-	ccs_kernel_domain.domainname = ccs_get_name(CCS_ROOT_NAME);
+	ccs_kernel_domain.domainname = ccs_get_name("<kernel>");
 	list_add_tail_rcu(&ccs_kernel_domain.list, &ccs_domain_list);
-	idx = ccs_read_lock();
-	if (ccs_find_domain(CCS_ROOT_NAME) != &ccs_kernel_domain)
-		panic("Can't register ccs_kernel_domain");
-#ifdef CONFIG_CCSECURITY_BUILTIN_INITIALIZERS
-	{
-		/* Load built-in policy. */
-		static char ccs_builtin_initializers[] __initdata
-			= CONFIG_CCSECURITY_BUILTIN_INITIALIZERS;
-		char *cp = ccs_builtin_initializers;
-		ccs_normalize_line(cp);
-		while (cp && *cp) {
-			char *cp2 = strchr(cp, ' ');
-			if (cp2)
-				*cp2++ = '\0';
-			ccs_write_transition_control(cp, false,
-				     CCS_TRANSITION_CONTROL_INITIALIZE);
-			cp = cp2;
-		}
-	}
-#endif
-	ccs_read_unlock(idx);
 }
