@@ -1,9 +1,9 @@
 /*
  * security/ccsecurity/proc_if.c
  *
- * Copyright (C) 2005-2010  NTT DATA CORPORATION
+ * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.8.0   2010/11/11
+ * Version: 1.8.3   2011/09/29
  */
 
 #include "internal.h"
@@ -65,9 +65,7 @@ static ssize_t ccs_write_self(struct file *file, const char __user *buf,
 		if (!r.granted)
 			error = -EPERM;
 		else
-			error = ccs_assign_domain(data, r.profile,
-						  ccs_current_domain()->group,
-						  true) ? 0 : -ENOENT;
+			error = ccs_assign_domain(data, true) ? 0 : -ENOENT;
 		ccs_read_unlock(idx);
 	} else
 		error = -EINVAL;
@@ -157,7 +155,7 @@ static int ccs_open(struct inode *inode, struct file *file)
  */
 static int ccs_release(struct inode *inode, struct file *file)
 {
-	return ccs_close_control(file);
+	return ccs_close_control(file->private_data);
 }
 
 /**
@@ -186,7 +184,7 @@ static unsigned int ccs_poll(struct file *file, poll_table *wait)
 static ssize_t ccs_read(struct file *file, char __user *buf, size_t count,
 			loff_t *ppos)
 {
-	return ccs_read_control(file, buf, count);
+	return ccs_read_control(file->private_data, buf, count);
 }
 
 /**
@@ -202,7 +200,7 @@ static ssize_t ccs_read(struct file *file, char __user *buf, size_t count,
 static ssize_t ccs_write(struct file *file, const char __user *buf,
 			 size_t count, loff_t *ppos)
 {
-	return ccs_write_control(file, buf, count);
+	return ccs_write_control(file->private_data, buf, count);
 }
 
 /* Operations for /proc/ccs/ interface. */
@@ -312,12 +310,9 @@ static void __init ccs_proc_init(void)
 	ccs_create_entry("domain_policy",    0600, ccs_dir, CCS_DOMAINPOLICY);
 	ccs_create_entry("exception_policy", 0600, ccs_dir,
 			 CCS_EXCEPTIONPOLICY);
-	ccs_create_entry("grant_log",        0400, ccs_dir, CCS_GRANTLOG);
-	ccs_create_entry("reject_log",       0400, ccs_dir, CCS_REJECTLOG);
-	ccs_create_entry(".domain_status",   0600, ccs_dir, CCS_DOMAIN_STATUS);
+	ccs_create_entry("audit",            0400, ccs_dir, CCS_AUDIT);
 	ccs_create_entry(".process_status",  0600, ccs_dir,
 			 CCS_PROCESS_STATUS);
-	ccs_create_entry("meminfo",          0600, ccs_dir, CCS_MEMINFO);
 	ccs_create_entry("stat",             0644, ccs_dir, CCS_STAT);
 	ccs_create_entry("profile",          0600, ccs_dir, CCS_PROFILE);
 	ccs_create_entry("manager",          0600, ccs_dir, CCS_MANAGER);
@@ -339,23 +334,15 @@ static void __init ccs_proc_init(void)
  */
 static int __init ccs_init_module(void)
 {
-	int i;
-	for (i = 0; i < CCS_MAX_POLICY; i++)
-		INIT_LIST_HEAD(&ccs_policy_list[i]);
-	for (i = 0; i < CCS_MAX_GROUP; i++)
-		INIT_LIST_HEAD(&ccs_group_list[i]);
-	for (i = 0; i < CCS_MAX_LIST; i++)
-		INIT_LIST_HEAD(&ccs_shared_list[i]);
 	if (ccsecurity_ops.disabled)
 		return -EINVAL;
-#if LINUX_VERSION_CODE <= KERNEL_VERSION(2, 6, 0)
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 0)
 	MOD_INC_USE_COUNT;
 #endif
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 19)
 	if (init_srcu_struct(&ccs_ss))
 		panic("Out of memory.");
 #endif
-	ccs_proc_init();
 	ccs_mm_init();
 	ccs_capability_init();
 	ccs_file_init();
@@ -364,6 +351,8 @@ static int __init ccs_init_module(void)
 	ccs_mount_init();
 	ccs_policy_io_init();
 	ccs_domain_init();
+	ccs_proc_init();
+	ccs_load_builtin_policy();
 	return 0;
 }
 
